@@ -552,10 +552,12 @@ def run_rml_func(_tuple):
     runner.run()
     api.load(rml_filename)
     api.trace(analyze=analyze)
+    api.save(rml_filename)
+    #print("DEBUG:: exports", exports)
     for e in exports:
         api.export(*e)
         if analyze==False:
-            pp.postprocess_RawRays(e[0], e[1], e[2], e[3])
+            pp.postprocess_RawRays(e[0], e[1], e[2], e[3], rml_filename)
     #time.sleep(0.1) # testing file creation issue
     try: 
         api.quit()
